@@ -42,8 +42,6 @@ class S3FileSystemOperator(object):
         :param data: A string contains the content of the file
         :param retry_count: retry count for S3 upload equals to three on default
         """
-
-        self.logger.debug(f"Writing to {bucket_name}/{file_name} started")
         writing_start = datetime.now()
         total_upload_tries = 0
         while total_upload_tries <= retry_count:
@@ -93,8 +91,6 @@ class S3FileSystemOperator(object):
         :param destination_path: The path where the file will be moved
         :param retry_count: retry count for S3 moving equals to three on default
         """
-
-        self.logger.debug(f"Moving from {source_path} to {destination_path} started")
         moving_start = datetime.now()
         total_move_tries = 0
         while total_move_tries <= retry_count:
@@ -130,8 +126,6 @@ class S3FileSystemOperator(object):
         :param retry_count: retry count for S3 reading equals to three on default
         :return: content of the target file in string format
         """
-
-        self.logger.debug(f"Reading from {bucket_name}/{file_name} started")
         reading_start = datetime.now()
         total_read_tries = 0
         while total_read_tries <= retry_count:
@@ -180,7 +174,6 @@ class S3Operator(object):
         :param bucket_name: Name of the bucket that file will be uploaded to.
         :param file_name: Name of the file (key of the file in s3).
         """
-        self.logger.debug(f"Upload to {bucket_name} started")
         upload_start = datetime.now()
         try:
             self.client.upload_file(path_to_file, bucket_name, file_name)
