@@ -11,8 +11,8 @@ def get_buffered_timestamp(timestamp: str, buffer_duration=BUFFER_DURATION_IN_MI
     :param buffer_duration: buffer duration in minutes
     :return: buffered start date
     """
-    start = datetime.strptime(timestamp, "%Y-%m-%d %H:%M:%S") - timedelta(
-        minutes=buffer_duration,
+    start = datetime_subtract(
+        datetime.strptime(timestamp, "%Y-%m-%d %H:%M:%S"), minutes=buffer_duration
     )
     return start.strftime("%Y-%m-%d %H:%M:%S")
 
@@ -26,3 +26,17 @@ def get_interval_duration(start: datetime, end: datetime):
     :return:
     """
     return round((end - start).total_seconds())
+
+
+def datetime_add(timestamp: datetime, seconds: int = None, minutes: int = None):
+    if seconds is not None:
+        return timestamp + timedelta(seconds=seconds)
+    if minutes is not None:
+        return timestamp + timedelta(minutes=minutes)
+
+
+def datetime_subtract(timestamp: datetime, seconds: int = None, minutes: int = None):
+    if seconds is not None:
+        return timestamp - timedelta(seconds=seconds)
+    if minutes is not None:
+        return timestamp - timedelta(minutes=minutes)
