@@ -6,6 +6,7 @@ from airflow_commons.internal.salesforce.http_utils import (
     get_headers,
     get_async_operation_url,
     get_async_operation_result_url,
+    get_async_operation_status_url,
     get_sync_operation_url,
     get_fetch_operation_url,
 )
@@ -62,7 +63,7 @@ class SalesForceOperator(object):
 
     def get_async_operation_result(self, request_id: str):
         """
-        Returns current status of an ongoing async process.
+        Returns result of an ongoing async process.
         :param request_id: ID of async request, can be found in the response of async request itself.
         :return:
         """
@@ -77,6 +78,23 @@ class SalesForceOperator(object):
         prep = request.prepare()
         return self.session.send(prep)
 
+    def get_async_operation_status(self, request_id: str):
+        """
+        Returns current status of an ongoing async process.
+        :param request_id: ID of async request, can be found in the response of async request itself.
+        :return:
+        """
+        url = get_async_operation_status_url(
+            base_url=self.connection.rest_instance_url, request_id=request_id
+        )
+        request = requests.Request(
+            method="GET",
+            url=url,
+            headers=get_headers(access_token=self.connection.access_token),
+        )
+        prep = request.prepare()
+        return self.session.send(prep)
+
     def _async_operation(self, key: str, data, method: str):
         """
         Internal method of async upsert and insert operations.
